Slot: deprecated element has exact replacement - LinkML Model

# Slot: deprecated element has exact replacement

When an element is deprecated, it can be automatically replaced by this uri or curie

URI: linkml:deprecated_element_has_exact_replacement

## Domain and Range

None → 0..1 Uriorcurie

## Parents

## Children

## Used by

- ClassDefinition
- CommonMetadata
- Definition
- Element
- EnumDefinition
- PermissibleValue
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Mappings: |  | IAO:0100001